set xbase 0
set ybase 32
set xwidth 25
set yheight 30
set xspacing 32
set yspacing 32
set scale 4
set fade_delay 0 ;#no fading
set position "left" ;#don't allow to override the position
